summaryrefslogtreecommitdiff
path: root/include/modules.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/modules.h')
-rw-r--r--include/modules.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/modules.h b/include/modules.h
index fd032fe87..4532549f1 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -827,9 +827,10 @@ class CoreExport Module : public Extensible
virtual void OnFindChan(const Anope::string &chname) { }
/** Called when a nick is dropped
* @param nick The nick
*/
- virtual void OnNickDrop(const Anope::string &nick) { }
+ virtual void OnNickDrop(User *u, NickAlias *na) { }
/** Called when a nick is forbidden
* @param na The nick alias of the forbidden nick
@@ -827,9 +827,10 @@ class CoreExport Module : public Extensible
virtual void OnFindChan(const Anope::string &chname) { }
/** Called when a nick is dropped
- * @param nick The nick
+ * @param u The user dropping the nick
+ * @param na The nick
*/